==> tecfy_core_package-0.1.102.tar.gz: lib/controllers/home/dashboard.controller.dart <==
part of tecfy_core_client_package;

class DashboardController extends BaseController {
  //List<DashboardItemBase> types;

  List<Dashboard> dashboards;
  Dashboard activeDashboard;
  String filterDate = 'Year';
  RefreshController refreshController =
      RefreshController(initialRefresh: false); // for pull to refrsh

  DashboardController(State<StatefulWidget> state) : super(state) {
    getType();
  }

  @override
  dispose() {
    refreshController?.dispose();
    super.dispose();
  }

  filterDateChanged(String val) {
    filterDate = val;
    refreshData();
    //setState();
  }

  getType() async {
    try {
      var typesResult = await TecfyBasicApp.apiService
          .httpGetDynamic('Dashboard/GetAllTypes');
      if (!typesResult.success) {
        typesResult.data =
            jsonDecode(ConfigService.getValueString('DashboardAllType'));
        typesResult.success = typesResult.data != null;
      }
      if (typesResult.success) {
        ConfigService.setValueString(
            'DashboardAllType', jsonEncode(typesResult.data));
        dashboards = typesResult.data
            .map<Dashboard>((d) => Dashboard.fromMap(d))
            .toList();
        activeDashboard = dashboards.length == 0 ? null : dashboards[0];
        setState();
        refreshData(true);
      }
    } catch (err) {
      print('XXXXXXXXXXXXX getType in dashboard  $err');
    }
  }

  Future<void> refreshData([bool fromCash = false]) async {
    if (activeDashboard == null) return;
    activeDashboard.items.forEach((t) => t.value = null);
    activeDashboard.items.forEach((t) => getData(t, fromCash));
    await Future.delayed(Duration(seconds: 1));
    refreshController.refreshCompleted();
  }

  Future<dynamic> getData(DashboardItemBase type,
      [bool fromCash = false]) async {
    if (type.value != null) return type.value;
    if (type.value == -1) return null;
    type.value = -1;

    OperationResult result;
    if (fromCash &&
        ConfigService.getValueString('DashboardType${type.dbName}$filterDate')
                .length >
            0)
      result = OperationResult(success: false);
    else
      result = await TecfyBasicApp.apiService.httpGetDynamic(
          'Dashboard/GetData/${type.dbName}?filterDate=$filterDate');
    if (!result.success) {
      result.data = jsonDecode(ConfigService.getValueString(
          'DashboardType${type.dbName}$filterDate'));
      result.success = result.data != null;
    }
    if (result.success) {
      ConfigService.setValueString(
          'DashboardType${type.dbName}', jsonEncode(result.data));
      type.value = result.data;
    } else {
      type.value = '0';
    }
    setState();
    return type.value;
  }
}

==> tecfy_core_package-1.0.5.tar.gz: lib/controllers/home/dashboard.controller.dart <==
part of tecfy_core_client_package;

class DashboardController extends BaseController {
  //List<DashboardItemBase> types;

  List<Dashboard>? dashboards;
  Dashboard? activeDashboard;
  String filterDate = 'Year';
  RefreshController refreshController =
      RefreshController(initialRefresh: false); // for pull to refrsh

  DashboardController(State<StatefulWidget> state) : super(state) {
    getType();
  }

  @override
  dispose() {
    refreshController.dispose();
    super.dispose();
  }

  filterDateChanged(String val) {
    filterDate = val;
    refreshData();
    //setState();
  }

  getType() async {
    try {
      var typesResult = await TecfyBasicApp.apiService
          .httpGetDynamic('Dashboard/GetAllTypes');
      if (!typesResult.success) {
        typesResult.data =
            jsonDecode(ConfigService.getValueString('DashboardAllType'));
        typesResult.success = typesResult.data != null;
      }
      if (typesResult.success) {
        ConfigService.setValueString(
            'DashboardAllType', jsonEncode(typesResult.data));
        dashboards = typesResult.data
            .map<Dashboard>((d) => Dashboard.fromMap(d))
            .toList();
        activeDashboard = dashboards?.length == 0 ? null : dashboards?[0];
        setState();
        refreshData(true);
      }
    } catch (err) {
      print('XXXXXXXXXXXXX getType in dashboard  $err');
    }
  }

  Future<void> refreshData([bool fromCash = false]) async {
    if (activeDashboard == null) return;
    activeDashboard?.items.forEach((t) => t.value = null);
    activeDashboard?.items.forEach((t) => getData(t, fromCash));
    await Future.delayed(Duration(seconds: 1));
    refreshController.refreshCompleted();
  }

  Future<dynamic> getData(DashboardItemBase type,
      [bool fromCash = false]) async {
    if (type.value != null) return type.value;
    if (type.value == -1) return null;
    type.value = -1;

    OperationResult result;
    if (fromCash &&
        ConfigService.getValueString('DashboardType${type.dbName}$filterDate')
                .length >
            0)
      result = OperationResult(success: false);
    else
      result = await TecfyBasicApp.apiService.httpGetDynamic(
          'Dashboard/GetData/${type.dbName}?filterDate=$filterDate');
    if (!result.success) {
      result.data = jsonDecode(ConfigService.getValueString(
          'DashboardType${type.dbName}$filterDate'));
      result.success = result.data != null;
    }
    if (result.success) {
      ConfigService.setValueString(
          'DashboardType${type.dbName}', jsonEncode(result.data));
      type.value = result.data;
    } else {
      type.value = '0';
    }
    setState();
    return type.value;
  }
}
